==> lxqt-globalkeys_0.14.2.orig.tar.xz: lxqt-globalkeys-0.14.2/config/translations/lxqt-config-globalkeyshortcuts_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>DefaultModel</name>
    <message>
        <location filename="../default_model.cpp" line="49"/>
        <source>Command</source>
        <translation>Comando</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="50"/>
        <source>DBus call</source>
        <translation>Chamada DBus</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="51"/>
        <source>Client</source>
        <translation>Cliente</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="141"/>
        <source>Id</source>
        <translation>ID</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="144"/>
        <source>Shortcut</source>
        <translation>Atalho</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="147"/>
        <source>Description</source>
        <translation>Descrição</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="150"/>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="153"/>
        <source>Info</source>
        <translation>Informação</translation>
    </message>
</context>
<context>
    <name>EditActionDialog</name>
    <message>
        <location filename="../edit_action_dialog.ui" line="14"/>
        <source>Edit Action</source>
        <translation>Editar ação</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="31"/>
        <source>&amp;Shortcut:</source>
        <translation>Atal&amp;ho:</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="74"/>
        <source>&amp;Description:</source>
        <translation>&amp;Descrição:</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="87"/>
        <source>&amp;Enabled</source>
        <translation>&amp;Ativado</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="102"/>
        <source>&amp;Command</source>
        <translation>&amp;Comando</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="109"/>
        <source>&amp;DBus message</source>
        <translation>Mensagem &amp;DBus</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="118"/>
        <source>Type:</source>
        <translation>Tipo:</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="164"/>
        <source>Co&amp;mmand:</source>
        <translation>Co&amp;mando:</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="206"/>
        <source>S&amp;ervice:</source>
        <translation>S&amp;erviço:</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="219"/>
        <source>&amp;Path:</source>
        <translation>Cami&amp;nho:</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="232"/>
        <source>&amp;Interface:</source>
        <translation>&amp;Interface:</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="245"/>
        <source>&amp;Method:</source>
        <translation>&amp;Método:</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../main_window.ui" line="14"/>
        <source>Global Actions Manager</source>
        <translation>Gestor de ações globais</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="55"/>
        <source>Add ...</source>
        <translation>Adicionar...</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="65"/>
        <source>Remove</source>
        <translation>Remover</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="75"/>
        <source>Modify ...</source>
        <translation>Modificar...</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="92"/>
        <source>Swap</source>
        <translation>Trocar</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="118"/>
        <source>Multiple actions behaviour:</source>
        <translation>Comportamento de ações múltiplas:</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="126"/>
        <source>First</source>
        <translation>Primeira</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="131"/>
        <source>Last</source>
        <translation>Última</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="136"/>
        <source>None</source>
        <translation>Nenhuma</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="141"/>
        <source>All</source>
        <translation>Todas</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="166"/>
        <source>Default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="186"/>
        <source>Close</source>
        <translation>Fechar</translation>
    </message>
    <message>
        <location filename="../main_window.cpp" line="187"/>
        <source>Restore Default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main_window.cpp" line="188"/>
        <source>Your defined shortcuts will be removed.
Do you want to proceed?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> lxqt-globalkeys_0.14.3.orig.tar.xz: lxqt-globalkeys-0.14.3/config/translations/lxqt-config-globalkeyshortcuts_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>DefaultModel</name>
    <message>
        <location filename="../default_model.cpp" line="49"/>
        <source>Command</source>
        <translation>Comando</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="50"/>
        <source>DBus call</source>
        <translation>Chamada DBus</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="51"/>
        <source>Client</source>
        <translation>Cliente</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="141"/>
        <source>Id</source>
        <translation>ID</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="144"/>
        <source>Shortcut</source>
        <translation>Atalho</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="147"/>
        <source>Description</source>
        <translation>Descrição</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="150"/>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <location filename="../default_model.cpp" line="153"/>
        <source>Info</source>
        <translation>Informação</translation>
    </message>
</context>
<context>
    <name>EditActionDialog</name>
    <message>
        <location filename="../edit_action_dialog.ui" line="14"/>
        <source>Edit Action</source>
        <translation>Editar ação</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="31"/>
        <source>&amp;Shortcut:</source>
        <translation>Atal&amp;ho:</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="74"/>
        <source>&amp;Description:</source>
        <translation>&amp;Descrição:</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="87"/>
        <source>&amp;Enabled</source>
        <translation>&amp;Ativado</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="102"/>
        <source>&amp;Command</source>
        <translation>&amp;Comando</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="109"/>
        <source>&amp;DBus message</source>
        <translation>Mensagem &amp;DBus</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="118"/>
        <source>Type:</source>
        <translation>Tipo:</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="164"/>
        <source>Co&amp;mmand:</source>
        <translation>Co&amp;mando:</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="206"/>
        <source>S&amp;ervice:</source>
        <translation>S&amp;erviço:</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="219"/>
        <source>&amp;Path:</source>
        <translation>Cami&amp;nho:</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="232"/>
        <source>&amp;Interface:</source>
        <translation>&amp;Interface:</translation>
    </message>
    <message>
        <location filename="../edit_action_dialog.ui" line="245"/>
        <source>&amp;Method:</source>
        <translation>&amp;Método:</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../main_window.ui" line="14"/>
        <source>Global Actions Manager</source>
        <translation>Gestor de ações globais</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="55"/>
        <source>Add ...</source>
        <translation>Adicionar...</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="65"/>
        <source>Remove</source>
        <translation>Remover</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="75"/>
        <source>Modify ...</source>
        <translation>Modificar...</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="92"/>
        <source>Swap</source>
        <translation>Trocar</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="118"/>
        <source>Multiple actions behaviour:</source>
        <translation>Comportamento de ações múltiplas:</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="126"/>
        <source>First</source>
        <translation>Primeira</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="131"/>
        <source>Last</source>
        <translation>Última</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="136"/>
        <source>None</source>
        <translation>Nada</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="141"/>
        <source>All</source>
        <translation>Todas</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="166"/>
        <source>Default</source>
        <translation>Padrão</translation>
    </message>
    <message>
        <location filename="../main_window.ui" line="186"/>
        <source>Close</source>
        <translation>Fechar</translation>
    </message>
    <message>
        <location filename="../main_window.cpp" line="187"/>
        <source>Restore Default</source>
        <translation>Repor predefinições</translation>
    </message>
    <message>
        <location filename="../main_window.cpp" line="188"/>
        <source>Your defined shortcuts will be removed.
Do you want to proceed?</source>
        <translation>Os atalhos definidos por si serão removidos.
Tem a certeza de que deseja continuar?</translation>
    </message>
</context>
</TS>
